summaryrefslogtreecommitdiffstats
path: root/src/include
diff options
context:
space:
mode:
Diffstat (limited to 'src/include')
-rw-r--r--src/include/usr/diag/prdf/prdfMain_ipl.H13
1 files changed, 10 insertions, 3 deletions
diff --git a/src/include/usr/diag/prdf/prdfMain_ipl.H b/src/include/usr/diag/prdf/prdfMain_ipl.H
index 96971a33d..933a3d47f 100644
--- a/src/include/usr/diag/prdf/prdfMain_ipl.H
+++ b/src/include/usr/diag/prdf/prdfMain_ipl.H
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2014,2015 */
+/* Contributors Listed Below - COPYRIGHT 2014,2017 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -41,12 +41,19 @@ namespace PRDF
{
/**
+ * @brief Initialize PRD system model and data (No System Lock)
+ * @return Error log if error occurs
+ */
+extern errlHndl_t noLock_initialize();
+
+/**
* @brief Restores hardware DRAM repairs to reflect what is stored in VPD.
* @param i_mba An MBA target.
* @return Non-SUCCESS if conditions are such that a callout had to be made,
* SUCCESS otherwise.
*/
-extern int32_t restoreDramRepairs( const TARGETING::TargetHandle_t i_mba );
+template<TARGETING::TYPE T>
+extern uint32_t restoreDramRepairs( const TARGETING::TargetHandle_t i_trgt );
/**
* @brief Analyzes IPL CE statistics during MNFG IPL
OpenPOWER on IntegriCloud
@@ -41,12 +41,19 @@ namespace PRDF
* @brief Restores hardware DRAM repairs to reflect what is stored in VPD.
- * @param i_mba An MBA target.
+ * @param i_trgt An MBA or MCA target.
* @return Non-SUCCESS if conditions are such that a callout had to be made,
* SUCCESS otherwise.